package com.landray.kmss.sys.attachment.jg;

import com.landray.kmss.common.dao.HQLInfo;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.common.model.IBaseModel;
import java.io.InputStream;
import com.landray.kmss.sys.attachment.model.SysAttMain;
import org.slf4j.LoggerFactory;
import com.landray.kmss.sys.attachment.service.ISysAttMainCoreInnerService;
import org.slf4j.Logger;

public abstract class AbstractSysAttachmentFunction
{
    protected static final Logger logger;
    private ISysAttMainCoreInnerService sysAttMainService;
    
    static {
        logger = LoggerFactory.getLogger(AbstractSysAttachmentFunction.class);
    }
    
    public AbstractSysAttachmentFunction() {
        this.sysAttMainService = null;
    }
    
    public ISysAttMainCoreInnerService getSysAttMainService() {
        return this.sysAttMainService;
    }
    
    public void setSysAttMainService(final ISysAttMainCoreInnerService sysAttMainService) {
        this.sysAttMainService = sysAttMainService;
    }
    
    protected void updateSysAttMain(final SysAttMain sysAttMain) throws Exception {
        if (sysAttMain != null) {
            sysAttMain.setInputStream((InputStream)null);
            this.sysAttMainService.update((IBaseModel)sysAttMain);
        }
        else if (AbstractSysAttachmentFunction.logger.isDebugEnabled()) {
            AbstractSysAttachmentFunction.logger.debug("附件为空导致更新失败");
        }
    }
    
    protected SysAttMain getSysAttMain(final String fdId, final String modelId, final String modelName, final String key) throws Exception {
        return this.getSysAttMain(fdId, modelId, modelName, key, false);
    }
    
    protected SysAttMain getSysAttMain(final String fdId, final String modelId, final String modelName, final String key, final boolean lock) throws Exception {
        SysAttMain att = null;
        if (StringUtil.isNotNull(fdId)) {
            att = (SysAttMain)this.getSysAttMainService().findByPrimaryKey(fdId, (Object)null, true);
            if (AbstractSysAttachmentFunction.logger.isDebugEnabled() && att != null) {
                AbstractSysAttachmentFunction.logger.debug("根据fdId查找得到文档：fdId:" + fdId);
            }
        }
        if (att == null) {
            if (StringUtil.isNull(modelId)) {
                return null;
            }
            final HQLInfo hqlInfo = new HQLInfo();
            String whereBlock = "sysAttMain.fdModelId = :fdModelId";
            hqlInfo.setParameter("fdModelId", (Object)modelId);
            if (StringUtil.isNotNull(modelName)) {
                whereBlock = String.valueOf(whereBlock) + " AND sysAttMain.fdModelName = :fdModelName";
                hqlInfo.setParameter("fdModelName", (Object)modelName);
            }
            if (StringUtil.isNotNull(key)) {
                whereBlock = String.valueOf(whereBlock) + " AND sysAttMain.fdKey = :fdKey";
                hqlInfo.setParameter("fdKey", (Object)key);
            }
            hqlInfo.setWhereBlock(whereBlock);
            final Object obj = this.getSysAttMainService().findFirstOne(hqlInfo);
            if (obj != null) {
                att = (SysAttMain)obj;
                if (AbstractSysAttachmentFunction.logger.isDebugEnabled() && att != null) {
                    AbstractSysAttachmentFunction.logger.debug("根据fdModelId、fdModelName、fdKey查找得到文档：fdModelId:" + modelId + "; fdModelName:" + modelName + "; fdKey" + key);
                }
            }
        }
        if (att != null) {
            att.setInputStream(this.getSysAttMainService().getInputStream(att.getFdId()));
        }
        return att;
    }
}
